summaryrefslogtreecommitdiffstats
path: root/certmanager/lib/ui/backendconfigwidget.cpp
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 22:19:39 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 22:19:39 +0000
commit36a36a5c1015aa0d03f4515c401e907ddb9d6291 (patch)
tree0212ba6d2c749043134005a41f2bd0379619d40f /certmanager/lib/ui/backendconfigwidget.cpp
parent4c6f8d69e2d1501837affb472c4eb8fec4462240 (diff)
downloadtdepim-36a36a5c1015aa0d03f4515c401e907ddb9d6291.tar.gz
tdepim-36a36a5c1015aa0d03f4515c401e907ddb9d6291.zip
rename the following methods:
tqparent parent tqmask mask git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdepim@1246260 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'certmanager/lib/ui/backendconfigwidget.cpp')
-rw-r--r--certmanager/lib/ui/backendconfigwidget.cpp14
1 files changed, 7 insertions, 7 deletions
diff --git a/certmanager/lib/ui/backendconfigwidget.cpp b/certmanager/lib/ui/backendconfigwidget.cpp
index 7869b1d2..1052cff5 100644
--- a/certmanager/lib/ui/backendconfigwidget.cpp
+++ b/certmanager/lib/ui/backendconfigwidget.cpp
@@ -76,8 +76,8 @@ namespace Kleo {
class Kleo::BackendListView : public KListView
{
public:
- BackendListView( BackendConfigWidget* tqparent, const char* name = 0 )
- : KListView( tqparent, name ) {}
+ BackendListView( BackendConfigWidget* parent, const char* name = 0 )
+ : KListView( parent, name ) {}
/// return backend for currently selected (/current) item. Used by Configure button.
const Kleo::CryptoBackend* currentBackend() const;
@@ -162,7 +162,7 @@ const Kleo::CryptoBackend* Kleo::BackendListView::currentBackend() const {
if ( !curItem ) // can't happen
return 0;
if ( lvi_cast<Kleo::ProtocolCheckListItem>( curItem ) )
- curItem = curItem->tqparent();
+ curItem = curItem->parent();
if ( const Kleo::BackendListViewItem * blvi = lvi_cast<Kleo::BackendListViewItem>( curItem ) )
return blvi->cryptoBackend();
return 0;
@@ -175,9 +175,9 @@ const Kleo::CryptoBackend* Kleo::BackendListView::chosenBackend( const char * pr
it.current() ; ++it )
if ( ProtocolCheckListItem * p = lvi_cast<ProtocolCheckListItem>( it.current() ) )
if ( p->isOn() && qstricmp( p->protocolName(), protocolName ) == 0 ) {
// OK that's the one. Now go up to the tqparent backend
// (need to do that in the listview since Protocol doesn't know it)
- if ( const BackendListViewItem * parItem = lvi_cast<BackendListViewItem>( it.current()->tqparent() ) )
+ if ( const BackendListViewItem * parItem = lvi_cast<BackendListViewItem>( it.current()->parent() ) )
return parItem->cryptoBackend();
}
return 0;
@@ -196,8 +196,8 @@ void Kleo::BackendListView::deselectAll( const char * protocolName, TQCheckListI
////
-Kleo::BackendConfigWidget::BackendConfigWidget( CryptoBackendFactory * factory, TQWidget * tqparent, const char * name, WFlags f )
- : TQWidget( tqparent, name, f ), d( 0 )
+Kleo::BackendConfigWidget::BackendConfigWidget( CryptoBackendFactory * factory, TQWidget * parent, const char * name, WFlags f )
+ : TQWidget( parent, name, f ), d( 0 )
{
assert( factory );
d = new Private();
@@ -175,9 +175,9 @@ const Kleo::CryptoBackend* Kleo::BackendListView::chosenBackend( const char * pr
if ( ProtocolCheckListItem * p = lvi_cast<ProtocolCheckListItem>( it.current() ) )
if ( p->isOn() && qstricmp( p->protocolName(), protocolName ) == 0 ) {
- // OK that's the one. Now go up to the tqparent backend
+ // OK that's the one. Now go up to the parent backend
// (need to do that in the listview since Protocol doesn't know it)